@@ -877,6 +877,24 @@ static char* cp850 [] = {
 
 
 
+/*========================================================================
+ * Name:	html_unisymbol_print
+ * Purpose:	Outputs arbitrary unicode symbol
+ * Args:	Unsigned Short.
+ * Returns:	String representing symbol.
+ *=======================================================================*/
+
+char *
+html_unisymbol_print (unsigned short c)
+{
+	char r[8];
+	snprintf(r, 8, "&#%04d;", c);
+	return my_strdup(r);
+}
+
+
+
+
 /*========================================================================
  * Name:	html_init
  * Purpose:	Generates the HTML output personality.
@@ -1098,5 +1116,7 @@ html_init (void)
 	op->symbol_translation_table = symbol;
 #endif
 
+	op->unisymbol_print = html_unisymbol_print;
+
 	return op;
 }
